### Import a certificate encrypt all the things

Owner

Enter a valid email.

Roles
Description

You must give a short description about this authority will be used for.

Public Certificate

Enter a valid certificate.

Private Key

Enter a valid certificate.

Certificate Signing Request (CSR)

Enter a valid certificate signing request.

Intermediate Certificate

Enter a valid certificate.

Custom Certificate Name